@@ -3,7 +3,6 @@
 package Pinto::Action::Edit;
 
 use Moose;
-use MooseX::Aliases;
 use MooseX::Types::Moose qw(Undef Str HashRef Bool);
 
 use Pinto::Types qw(StackName);
@@ -12,7 +11,7 @@ use namespace::autoclean;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.051'; # VERSION
+our $VERSION = '0.052'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -23,7 +22,6 @@ extends qw( Pinto::Action );
 has stack => (
     is       => 'ro',
     isa      => StackName | Undef,
-    alias    => 'operative_stack',
     default  => undef,
     coerce   => 1,
 );
@@ -44,10 +42,6 @@ has default => (
 
 #------------------------------------------------------------------------------
 
-with qw( Pinto::Role::Operator );
-
-#------------------------------------------------------------------------------
-
 sub execute {
     my ($self) = @_;
 
@@ -78,7 +72,7 @@ Pinto::Action::Edit - Change stack properties
 
 =head1 VERSION
 
-version 0.051
+version 0.052
 
 =head1 AUTHOR
 
