@@ -11,7 +11,7 @@ use namespace::autoclean;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.051'; # VERSION
+our $VERSION = '0.052'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -19,10 +19,6 @@ extends qw( Pinto::Action );
 
 #------------------------------------------------------------------------------
 
-with qw( Pinto::Role::Reporter );
-
-#------------------------------------------------------------------------------
-
 has stack => (
     is        => 'ro',
     isa       => StackName | StackAt | StackDefault,
@@ -59,7 +55,7 @@ has distributions => (
 has format => (
     is        => 'ro',
     isa       => Str,
-    default   => "%m%s%y %-40n %12v  %a/%f\n",
+    default   => "%m%s%y %-40n %12v  %a/%f",
     predicate => 'has_format',
     lazy      => 1,
 );
@@ -111,7 +107,7 @@ sub execute {
         # If listing all stacks, then include the stack name
         # in the listing, unless a custom format has been given
         $format = $self->has_format ? $self->format
-                                    : "%m%s%y %-12k %-40n %12v  %p\n";
+                                    : "%m%s%y %-12k %-40n %12v  %p";
     }
     else{
         # Otherwise, list only the named stack, falling back to
@@ -142,7 +138,7 @@ sub execute {
     my $rs = $self->repos->db->select_registrations($where, $attrs);
 
     while( my $registration = $rs->next ) {
-        print { $self->out } $registration->to_string($format);
+        $self->say($registration->to_string($format));
     }
 
     return $self->result;
@@ -168,7 +164,7 @@ Pinto::Action::List - List the contents of a stack
 
 =head1 VERSION
 
-version 0.051
+version 0.052
 
 =head1 AUTHOR
 
