@@ -3,7 +3,6 @@
 package Pinto::Action::Pull;
 
 use Moose;
-use MooseX::Aliases;
 use MooseX::Types::Moose qw(Undef Bool);
 
 use Pinto::Types qw(Specs StackName);
@@ -12,7 +11,7 @@ use namespace::autoclean;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.051'; # VERSION
+our $VERSION = '0.052'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -20,6 +19,10 @@ extends qw( Pinto::Action );
 
 #------------------------------------------------------------------------------
 
+with qw( Pinto::Role::Committable );
+
+#------------------------------------------------------------------------------
+
 has targets => (
     isa      => Specs,
     traits   => [ qw(Array) ],
@@ -32,7 +35,6 @@ has targets => (
 has stack => (
     is        => 'ro',
     isa       => StackName | Undef,
-    alias     => 'operative_stack',
     default   => undef,
     coerce    => 1,
 );
@@ -51,20 +53,28 @@ has norecurse => (
     default   => 0,
 );
 
-#------------------------------------------------------------------------------
 
-with qw( Pinto::Role::Operator );
+has dryrun => (
+    is      => 'ro',
+    isa     => Bool,
+    default => 0,
+);
 
 #------------------------------------------------------------------------------
 
+
 sub execute {
     my ($self) = @_;
 
-    my $stack = $self->repos->get_stack(name => $self->stack);
-
+    my $stack = $self->repos->open_stack(name => $self->stack);
     $self->_execute($_, $stack) for $self->targets;
+    $self->result->changed if $stack->refresh->has_changed;
 
-    $self->repos->clean_files if $self->dryrun;
+    if ( not ($self->dryrun and $stack->has_changed) ) {
+        my $message_primer = $stack->head_revision->change_details;
+        $stack->close(message => $self->edit_message(primer => $message_primer));
+        $self->repos->write_index(stack => $stack);
+    }
 
     return $self->result;
 }
@@ -77,14 +87,13 @@ sub _execute {
     my ($dist, $did_pull) = $self->repos->get_or_pull( target => $target,
                                                        stack  => $stack );
 
+    $dist->pin( stack => $stack ) if $dist && $self->pin;
+
     if ($dist and not $self->norecurse) {
         my @prereq_dists = $self->repos->pull_prerequisites( dist  => $dist,
                                                              stack => $stack );
-        $did_pull += @prereq_dists;
     }
 
-    $self->result->changed if $did_pull;
-
     return;
 }
 
@@ -108,7 +117,7 @@ Pinto::Action::Pull - Pull upstream distributions into the repository
 
 =head1 VERSION
 
-version 0.051
+version 0.052
 
 =head1 AUTHOR
 
