@@ -3,7 +3,6 @@
 package Pinto::Action::Unpin;
 
 use Moose;
-use MooseX::Aliases;
 use MooseX::Types::Moose qw(Undef);
 
 use Pinto::Types qw(Specs StackName);
@@ -13,7 +12,7 @@ use namespace::autoclean;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.051'; # VERSION
+our $VERSION = '0.052'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -21,6 +20,10 @@ extends qw( Pinto::Action );
 
 #------------------------------------------------------------------------------
 
+with qw( Pinto::Role::Committable );
+
+#------------------------------------------------------------------------------
+
 has targets => (
     isa      => Specs,
     traits   => [ qw(Array) ],
@@ -33,24 +36,25 @@ has targets => (
 has stack => (
     is        => 'ro',
     isa       => Undef | StackName,
-    alias     => 'operative_stack',
     default   => undef,
     coerce    => 1,
 );
 
 #------------------------------------------------------------------------------
 
-with qw( Pinto::Role::Operator );
-
-#------------------------------------------------------------------------------
-
 sub execute {
     my ($self) = @_;
 
-    my $stack = $self->repos->get_stack(name => $self->stack);
+    my $stack = $self->repos->open_stack(name => $self->stack);
 
     $self->_execute($_, $stack) for $self->targets;
 
+    return $self->result if $self->dryrun or not $stack->refresh->has_changed;
+
+    my $message_primer = $stack->head_revision->change_details;
+
+    $stack->close(message => $self->edit_message(primer => $message_primer));
+
     return $self->result->changed;
 }
 
@@ -83,7 +87,7 @@ sub _execute {
 
 
     $self->notice("Unpinning $dist from stack $stack");
-    $dist->unpin(stack => $stack);
+    $self->result->changed if $dist->unpin(stack => $stack);
 
     return;
 }
@@ -108,7 +112,7 @@ Pinto::Action::Unpin - Loosen a package that has been pinned
 
 =head1 VERSION
 
-version 0.051
+version 0.052
 
 =head1 AUTHOR
 
