@@ -1,59 +1,67 @@
+# ABSTRACT: Construct Action objects
+
 package Pinto::ActionFactory;
 
-# ABSTRACT: Factory class for making Actions
-
 use Moose;
+use MooseX::Types::Moose qw(Str);
 
 use Class::Load;
 
-#------------------------------------------------------------------------------
-
-our $VERSION = '0.016'; # VERSION
+use Pinto::Exception qw(throw);
 
 #------------------------------------------------------------------------------
-# Attributes
 
-has idxmgr => (
+our $VERSION = '0.052'; # VERSION
+
+#------------------------------------------------------------------------------
+
+has repos => (
     is       => 'ro',
-    isa      => 'Pinto::IndexManager',
+    isa      => 'Pinto::Repository',
     required => 1,
 );
 
-has store => (
-    is       => 'ro',
-    isa      => 'Pinto::Store',
-    required => 1,
+
+has action_class_namespace => (
+    is        => 'ro',
+    isa       => Str,
+    default   => 'Pinto::Action',
 );
 
 #------------------------------------------------------------------------------
-# Roles
 
 with qw( Pinto::Role::Configurable
          Pinto::Role::Loggable );
 
 #------------------------------------------------------------------------------
-# Methods
 
 sub create_action {
-    my ($self, $action_name, %args) = @_;
+    my ($self, $action_name, %action_args) = @_;
 
-    my $action_class = "Pinto::Action::$action_name";
-    Class::Load::load_class( $action_class );
-
-    return $action_class->new( config => $self->config(),
-                               logger => $self->logger(),
-                               idxmgr => $self->idxmgr(),
-                               store  => $self->store(),
-                               %args );
+    @action_args{qw(logger repos)} = ($self->logger, $self->repos);
+    my $action_class = $self->load_class_for_action(name => $action_name);
+    my $action = $action_class->new(%action_args);
 
+    return $action;
 }
 
 #------------------------------------------------------------------------------
 
-__PACKAGE__->meta()->make_immutable();
+sub load_class_for_action {
+    my ($self, %args) = @_;
+
+    my $action_name = ucfirst $args{name} || throw 'Must specify an action name';
+    my $action_class = $self->action_class_namespace . '::' . $action_name;
+    Class::Load::load_class($action_class);
+
+    return $action_class;
+}
 
 #------------------------------------------------------------------------------
 
+__PACKAGE__->meta->make_immutable;
+
+#------------------------------------------------------------------------------
 1;
 
 
@@ -64,11 +72,11 @@ __PACKAGE__->meta()->make_immutable();
 
 =head1 NAME
 
-Pinto::ActionFactory - Factory class for making Actions
+Pinto::ActionFactory - Construct Action objects
 
 =head1 VERSION
 
-version 0.016
+version 0.052
 
 =head1 AUTHOR
 
