@@ -1,7 +1,7 @@
-package Pinto::Initializer;
-
 # ABSTRACT: Initializes a new Pinto repository
 
+package Pinto::Initializer;
+
 use Moose;
 
 use autodie;
@@ -9,6 +9,7 @@ use autodie;
 use PerlIO::gzip;
 use Path::Class;
 
+use Pinto::Util;
 use Pinto::Database;
 use Pinto::Repository;
 
@@ -16,7 +17,7 @@ use namespace::autoclean;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.051'; # VERSION
+our $VERSION = '0.052'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -25,6 +26,14 @@ with qw( Pinto::Role::Configurable
 
 #------------------------------------------------------------------------------
 
+# TODO: Can we use proper Moose attributes here, rather than passing a big
+# hash of attributes to the init() method.  I seem to remember that I needed
+# to do this so I would have something to give to $config->write.  But I'm
+# not convinced this was the right solution.  It would probably be better
+# to just put all the config attributes into repository props anyway.
+
+#------------------------------------------------------------------------------
+
 
 sub init {
     my ($self, %args) = @_;
@@ -67,9 +76,10 @@ sub init {
     # Write authors index
     $self->_write_mailrc;
 
-    # Write the packages index
-    $self->_write_index;
+    # Create the inital stack, if needed
+    $self->_create_stack(name => $args{stack}) unless $args{bare};
 
+    # Log message for posterity
     $self->notice("Created new repository at directory $root_dir");
 
     return $self;
@@ -81,7 +91,7 @@ sub init {
 sub _write_modlist {
     my ($self) = @_;
 
-    my $modlist_file = $self->config->modules_dir->file('03modlist.data.gz');
+    my $modlist_file = $self->config->modlist_file;
     open my $fh, '>:gzip', $modlist_file;
     print {$fh} $self->_modlist_data();
     close $fh;
@@ -95,7 +105,7 @@ sub _write_modlist {
 sub _write_mailrc {
     my ($self) = @_;
 
-    my $mailrc_file = $self->config->mailrc_file();
+    my $mailrc_file = $self->config->mailrc_file;
     open my $fh, '>:gzip', $mailrc_file;
     print {$fh} '';
     close $fh;
@@ -138,20 +148,26 @@ sub _create_db {
     my $db = Pinto::Database->new( config => $self->config );
     $db->deploy;
 
-    my $stack_attrs = {name => 'init', is_default => 1};
-    my $stack = $db->schema->resultset('Stack')->create($stack_attrs);
-    $stack->set_property('description' => 'the initial stack');
-
     return;
 }
 
 #------------------------------------------------------------------------------
 
-sub _write_index {
-    my ($self) = @_;
+sub _create_stack {
+    my ($self, %args) = @_;
 
-    my $repos = Pinto::Repository->new( config => $self->config );
-    $repos->write_index;
+    my $stk_name  = Pinto::Util::normalize_stack_name( $args{name} || 'init');
+    my $stk_description = $args{description} || 'the initial stack';
+
+    my $repos = Pinto::Repository->new(config => $self->config);
+
+    my $stack = $repos->create_stack(name => $stk_name, is_default => 1);
+
+    $stack->set_property(description => $stk_description);
+
+    $repos->write_index(stack => $stack);
+
+    $stack->close(message => 'Created initial stack');
 
     return;
 }
@@ -176,7 +192,7 @@ Pinto::Initializer - Initializes a new Pinto repository
 
 =head1 VERSION
 
-version 0.051
+version 0.052
 
 =head1 AUTHOR
 
